@@ -26,11 +26,9 @@
 #include <QPushButton>
 #include <QLabel>
 #include <QVBoxLayout>
-#include <QGridLayout>
 
 #include <klocalizedstring.h>
 
-#include "gui/guiprofile.h"
 #include "gui/mixdevicewidget.h"
 #include "core/ControlManager.h"
 #include "core/mixdevice.h"
@@ -181,7 +179,7 @@ void DialogViewConfiguration::moveSelection(DialogViewConfigurationWidget *from,
     const QList<QListWidgetItem *> sel = from->selectedItems();
     from->selectionModel()->clearSelection();
 
-    for (QListWidgetItem *item : qAsConst(sel))
+    for (QListWidgetItem *item : std::as_const(sel))
     {
         from->takeItem(from->row(item));
         to->addItem(item);
@@ -305,7 +303,7 @@ void DialogViewConfiguration::apply()
    prepareControls(model, false, oldControlset, newControlset);
 
    // -2- Copy all mandatory "catch-all" controls form the old to the new ControlSet  *******
-   for (const ProfControl *pctl : qAsConst(oldControlset))
+   for (const ProfControl *pctl : std::as_const(oldControlset))
    {
        if ( pctl->isMandatory() ) {
            ProfControl* newCtl = new ProfControl(*pctl);
@@ -352,7 +350,7 @@ void DialogViewConfiguration::prepareControls(QAbstractItemModel* model, bool is
 
          // -3- Insert it in the new ControlSet **************************
 //         qCDebug(KMIX_LOG) << "Should add to new ControlSet: " << ctlId;
-        for (const ProfControl *control : qAsConst(oldCtlSet))
+        for (const ProfControl *control : std::as_const(oldCtlSet))
         {
             //qCDebug(KMIX_LOG) << " checking " << control->id;
             QRegExp idRegexp(control->id());
